import { useEffect, useState } from 'react';
import { Button, DialogContent, Icon, Input } from '@/lib/components';
import { UDF } from '@/config/UDF_LIST'; // TODO PLEASE MOVE THIS TO A REASONABLE LOCATION
import { Node } from 'reactflow';
import { NumberFilterTypes } from 'ts-common';

export type MetaPillClickType = 'degreeleft' | 'community_detection';

export function ProceduresPanel(props: {
  udfList: UDF[];
  selection: Node[];
  handleClose: () => void;
  onClick: (type: MetaPillClickType, config: { op: string; right: number }) => void;
}) {
  const [procedures, setProcedures] = useState([]);
  const [procedureType, setProcedureType] = useState('predicate');
  const [selectedOperator, setSelectedOperator] = useState(NumberFilterTypes.LESS_THAN);
  const [filterValue, setFilterValue] = useState(2);
  const [activeFunction, setActiveFunction] = useState<MetaPillClickType | null>(null);

  // Available operators for filtering
  const operators = [
    { value: NumberFilterTypes.LESS_THAN, label: 'Less Than (<)' },
    { value: NumberFilterTypes.LESS_THAN_EQUAL, label: 'Less Than or Equal (≤)' },
    { value: NumberFilterTypes.EQUAL, label: 'Equal (=)' },
    { value: NumberFilterTypes.GREATER_THAN_EQUAL, label: 'Greater Than or Equal (≥)' },
    { value: NumberFilterTypes.GREATER_THAN, label: 'Greater Than (>)' },
  ];

  useEffect(() => {
    // get all procedures based on content of meta pill
  }, []);

  const handleApplyFunction = () => {
    if (activeFunction) {
      props.onClick(activeFunction, {
        op: selectedOperator,
        right: filterValue
      });
      // Reset active function after applying
      setActiveFunction(null);
    }
  };

  return (
    <DialogContent className="w-fit rounded-none">
      <div className="card">
        <h1 className="card-title mb-2 mx-auto">Meta-pill configuration</h1>
        <h3>{procedureType} functions available:</h3>

        <div className="flex flex-wrap gap-2 mb-4">
          <Button
            label="Degree Left"
            onClick={() => setActiveFunction('degreeleft')}
            className={activeFunction === 'degreeleft' ? 'bg-orange-500 text-white' : ''}
          />
          <Button
            label="Community Detection"
            onClick={() => setActiveFunction('community_detection')}
            className={activeFunction === 'community_detection' ? 'bg-orange-500 text-white' : ''}
          />
        </div>

        {activeFunction && (
          <div className="function-config border p-4 rounded mb-4">
            <h4 className="mb-2">{activeFunction === 'degreeleft' ? 'Degree Left' : 'Community Detection'} Configuration</h4>

            {activeFunction === 'degreeleft' && (
              <>
                <div className="mb-3">
                  <label className="block mb-1">Operator:</label>
                  <select
                    value={selectedOperator}
                    onChange={(e) => setSelectedOperator(e.target.value)}
                    className="w-full p-2 border rounded"
                  >
                    {operators.map(op => (
                      <option key={op.value} value={op.value}>{op.label}</option>
                    ))}
                  </select>
                </div>

                <div className="mb-3">
                  <label className="block mb-1">Value:</label>
                  <Input
                    type="number"
                    value={filterValue}
                    onChange={(e) => setFilterValue(e || 0)}
                    min={0}
                    className="w-full"
                  />
                </div>
              </>
            )}

            <Button
              label="Apply"
              onClick={handleApplyFunction}
              className="w-full bg-orange-500 text-white"
            />
          </div>
        )}

        <Button
          label="Close"
          onClick={props.handleClose}
          className="mt-4 w-full"
        />
      </div>
    </DialogContent>
  );
}
